==> stepfunctions-1.60.0-sources.jar: software/amazon/awscdk/services/stepfunctions/WaitProps.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * Properties for defining a Wait state.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.9.0 (build 5c646d5)", date = "2020-08-19T23:25:13.497Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.WaitProps")
@software.amazon.jsii.Jsii.Proxy(WaitProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface WaitProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Wait duration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.WaitTime getTime();

    /**
     * An optional description for this state.
     * <p>
     * Default: No comment
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getComment() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link WaitProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WaitProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<WaitProps> {
        private software.amazon.awscdk.services.stepfunctions.WaitTime time;
        private java.lang.String comment;

        /**
         * Sets the value of {@link WaitProps#getTime}
         * @param time Wait duration. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder time(software.amazon.awscdk.services.stepfunctions.WaitTime time) {
            this.time = time;
            return this;
        }

        /**
         * Sets the value of {@link WaitProps#getComment}
         * @param comment An optional description for this state.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder comment(java.lang.String comment) {
            this.comment = comment;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WaitProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public WaitProps build() {
            return new Jsii$Proxy(time, comment);
        }
    }

    /**
     * An implementation for {@link WaitProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WaitProps {
        private final software.amazon.awscdk.services.stepfunctions.WaitTime time;
        private final java.lang.String comment;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.time = this.jsiiGet("time", software.amazon.awscdk.services.stepfunctions.WaitTime.class);
            this.comment = this.jsiiGet("comment", java.lang.String.class);
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        private Jsii$Proxy(final software.amazon.awscdk.services.stepfunctions.WaitTime time, final java.lang.String comment) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.time = java.util.Objects.requireNonNull(time, "time is required");
            this.comment = comment;
        }

        @Override
        public software.amazon.awscdk.services.stepfunctions.WaitTime getTime() {
            return this.time;
        }

        @Override
        public java.lang.String getComment() {
            return this.comment;
        }

        @Override
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("time", om.valueToTree(this.getTime()));
            if (this.getComment() != null) {
                data.set("comment", om.valueToTree(this.getComment()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions.WaitProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public boolean equals(Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WaitProps.Jsii$Proxy that = (WaitProps.Jsii$Proxy) o;

            if (!time.equals(that.time)) return false;
            return this.comment != null ? this.comment.equals(that.comment) : that.comment == null;
        }

        @Override
        public int hashCode() {
            int result = this.time.hashCode();
            result = 31 * result + (this.comment != null ? this.comment.hashCode() : 0);
            return result;
        }
    }
}

==> stepfunctions-1.101.0-sources.jar: software/amazon/awscdk/services/stepfunctions/WaitProps.java <==
package software.amazon.awscdk.services.stepfunctions;

/**
 * Properties for defining a Wait state.
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.28.0 (build 1801f4f)", date = "2021-04-28T11:07:42.265Z")
@software.amazon.jsii.Jsii(module = software.amazon.awscdk.services.stepfunctions.$Module.class, fqn = "@aws-cdk/aws-stepfunctions.WaitProps")
@software.amazon.jsii.Jsii.Proxy(WaitProps.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface WaitProps extends software.amazon.jsii.JsiiSerializable {

    /**
     * Wait duration.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull software.amazon.awscdk.services.stepfunctions.WaitTime getTime();

    /**
     * An optional description for this state.
     * <p>
     * Default: No comment
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.String getComment() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link WaitProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link WaitProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<WaitProps> {
        private software.amazon.awscdk.services.stepfunctions.WaitTime time;
        private java.lang.String comment;

        /**
         * Sets the value of {@link WaitProps#getTime}
         * @param time Wait duration. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder time(software.amazon.awscdk.services.stepfunctions.WaitTime time) {
            this.time = time;
            return this;
        }

        /**
         * Sets the value of {@link WaitProps#getComment}
         * @param comment An optional description for this state.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder comment(java.lang.String comment) {
            this.comment = comment;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link WaitProps}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public WaitProps build() {
            return new Jsii$Proxy(time, comment);
        }
    }

    /**
     * An implementation for {@link WaitProps}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements WaitProps {
        private final software.amazon.awscdk.services.stepfunctions.WaitTime time;
        private final java.lang.String comment;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.time = software.amazon.jsii.Kernel.get(this, "time", software.amazon.jsii.NativeType.forClass(software.amazon.awscdk.services.stepfunctions.WaitTime.class));
            this.comment = software.amazon.jsii.Kernel.get(this, "comment", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final software.amazon.awscdk.services.stepfunctions.WaitTime time, final java.lang.String comment) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.time = java.util.Objects.requireNonNull(time, "time is required");
            this.comment = comment;
        }

        @Override
        public final software.amazon.awscdk.services.stepfunctions.WaitTime getTime() {
            return this.time;
        }

        @Override
        public final java.lang.String getComment() {
            return this.comment;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("time", om.valueToTree(this.getTime()));
            if (this.getComment() != null) {
                data.set("comment", om.valueToTree(this.getComment()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@aws-cdk/aws-stepfunctions.WaitProps"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            WaitProps.Jsii$Proxy that = (WaitProps.Jsii$Proxy) o;

            if (!time.equals(that.time)) return false;
            return this.comment != null ? this.comment.equals(that.comment) : that.comment == null;
        }

        @Override
        public final int hashCode() {
            int result = this.time.hashCode();
            result = 31 * result + (this.comment != null ? this.comment.hashCode() : 0);
            return result;
        }
    }
}
